==> igniteui-react-18.7.0-beta.2.tgz: package/esm5/lib/igr-switch.js <==
import { __assign, __extends } from "tslib";
import * as React from 'react';
import { IgrCheckboxBase } from "./igr-checkbox-base";
import { Switch } from "./Switch";
import { IgcSwitchComponent, defineComponents } from "igniteui-webcomponents";
import { isValidProp } from "igniteui-react-core";
/**
 * Similar to a checkbox, a switch controls the state of a single setting on or off.
*/
var IgrSwitch = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrSwitch, _super);
    function IgrSwitch(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcSwitchComponent);
        return _this;
    }
    IgrSwitch.prototype.createImplementation = function () {
        return new Switch();
    };
    Object.defineProperty(IgrSwitch.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrSwitch.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrSwitch.prototype.render = function () {
        var _this = this;
        var nativePropsName = Object.keys(this.props).filter(function (prop) { return !isValidProp(_this, prop) && prop !== "originalRef"; });
        var nativeProps = {};
        nativePropsName.forEach(function (propName) {
            nativeProps[propName] = _this.props[propName];
        });
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-switch", __assign(__assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    };
    IgrSwitch.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    return IgrSwitch;
}(IgrCheckboxBase));
export { IgrSwitch };

==> igniteui-react-18.7.5-beta.2.tgz: package/esm5/lib/igr-switch.js <==
import { __assign, __extends } from "tslib";
import * as React from 'react';
import { IgrCheckboxBase } from "./igr-checkbox-base";
import { Switch } from "./Switch";
import { IgcSwitchComponent, defineComponents } from "igniteui-webcomponents";
import { isValidProp } from "igniteui-react-core";
/**
 * Similar to a checkbox, a switch controls the state of a single setting on or off.
*/
var IgrSwitch = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrSwitch, _super);
    function IgrSwitch(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcSwitchComponent);
        return _this;
    }
    IgrSwitch.prototype.createImplementation = function () {
        return new Switch();
    };
    Object.defineProperty(IgrSwitch.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrSwitch.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrSwitch.prototype.render = function () {
        var _this = this;
        var nativePropsName = Object.keys(this.props).filter(function (prop) { return !isValidProp(_this, prop) && prop !== "originalRef" && prop !== "className"; });
        var nativeProps = {};
        nativePropsName.forEach(function (propName) {
            nativeProps[propName] = _this.props[propName];
        });
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-switch", __assign(__assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    };
    IgrSwitch.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    return IgrSwitch;
}(IgrCheckboxBase));
export { IgrSwitch };
